Class: Google::Cloud::Workstations::V1::WorkstationCluster::PrivateClusterConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1::WorkstationCluster::PrivateClusterConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1/workstations.rb
Overview
Configuration options for private workstation clusters.
Instance Attribute Summary collapse
-
#allowed_projects ⇒ ::Array<::String>
Optional.
-
#cluster_hostname ⇒ ::String
readonly
Output only.
-
#enable_private_endpoint ⇒ ::Boolean
Immutable.
-
#service_attachment_uri ⇒ ::String
readonly
Output only.
Instance Attribute Details
#allowed_projects ⇒ ::Array<::String>
Returns Optional. Additional projects that are allowed to attach to the workstation cluster's service attachment. By default, the workstation cluster's project and the VPC host project (if different) are allowed.
151 152 153 154 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 151 class PrivateClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cluster_hostname ⇒ ::String (readonly)
Returns Output only. Hostname for the workstation cluster. This field will be populated only when private endpoint is enabled. To access workstations in the workstation cluster, create a new DNS zone mapping this domain name to an internal IP address and a forwarding rule mapping that address to the service attachment.
151 152 153 154 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 151 class PrivateClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_private_endpoint ⇒ ::Boolean
Returns Immutable. Whether Workstations endpoint is private.
151 152 153 154 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 151 class PrivateClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_attachment_uri ⇒ ::String (readonly)
Returns Output only. Service attachment URI for the workstation cluster. The service attachment is created when private endpoint is enabled. To access workstations in the workstation cluster, configure access to the managed service using Private Service Connect.
151 152 153 154 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 151 class PrivateClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |