Class: Google::Cloud::Workstations::V1::WorkstationConfig::Container
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1::WorkstationConfig::Container
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1/workstations.rb
Overview
A Docker container.
Defined Under Namespace
Classes: EnvEntry
Instance Attribute Summary collapse
-
#args ⇒ ::Array<::String>
Optional.
-
#command ⇒ ::Array<::String>
Optional.
-
#env ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#image ⇒ ::String
Optional.
-
#run_as_user ⇒ ::Integer
Optional.
-
#working_dir ⇒ ::String
Optional.
Instance Attribute Details
#args ⇒ ::Array<::String>
Returns Optional. Arguments passed to the entrypoint.
924 925 926 927 928 929 930 931 932 933 934 935 936 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 924 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#command ⇒ ::Array<::String>
Returns Optional. If set, overrides the default ENTRYPOINT specified by the image.
924 925 926 927 928 929 930 931 932 933 934 935 936 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 924 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#env ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Environment variables passed to the container's entrypoint.
924 925 926 927 928 929 930 931 932 933 934 935 936 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 924 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#image ⇒ ::String
Returns Optional. A Docker container image that defines a custom environment.
Cloud Workstations provides a number of
preconfigured
images,
but you can create your own
custom container
images.
If using a private image, the host.gceInstance.serviceAccount field
must be specified in the workstation configuration.
If using a custom container image, the service account must have
Artifact Registry
Reader
permission to pull the specified image. Otherwise, the image must be
publicly accessible.
924 925 926 927 928 929 930 931 932 933 934 935 936 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 924 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#run_as_user ⇒ ::Integer
Returns Optional. If set, overrides the USER specified in the image with the given uid.
924 925 926 927 928 929 930 931 932 933 934 935 936 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 924 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#working_dir ⇒ ::String
Returns Optional. If set, overrides the default DIR specified by the image.
924 925 926 927 928 929 930 931 932 933 934 935 936 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 924 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class EnvEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |