Class: Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1/workstations.rb

Overview

An ephemeral directory which won't persist across workstation sessions. It is freshly created on every workstation start operation.

Defined Under Namespace

Classes: GcePersistentDisk

Instance Attribute Summary collapse

Instance Attribute Details

#gce_pd::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk

Returns An EphemeralDirectory backed by a Compute Engine persistent disk.

Returns:



835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 835

class EphemeralDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An EphemeralDirectory is backed by a Compute Engine persistent disk.
  # @!attribute [rw] disk_type
  #   @return [::String]
  #     Optional. Type of the disk to use. Defaults to `"pd-standard"`.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. Must
  #     be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_image source_image}
  #     is set. Must be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#read_only read_only}
  #     is false. Updating
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     will update content in the ephemeral directory after the workstation is
  #     restarted.
  #
  #     Only file systems supported by Container-Optimized OS (COS)
  #     are explicitly supported. For a list of supported file systems, see
  #     [the filesystems available in Container-Optimized
  #     OS](https://cloud.google.com/container-optimized-os/docs/concepts/supported-filesystems).
  #
  #     This field is mutable.
  # @!attribute [rw] source_image
  #   @return [::String]
  #     Optional. Name of the disk image to use as the source for the disk.
  #     Must be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     is set. Updating
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_image source_image}
  #     will update content in the ephemeral directory after the workstation is
  #     restarted.
  #
  #     Only file systems supported by Container-Optimized OS (COS)
  #     are explicitly supported. For a list of supported file systems, please
  #     refer to the [COS
  #     documentation](https://cloud.google.com/container-optimized-os/docs/concepts/supported-filesystems).
  #
  #     This field is mutable.
  # @!attribute [rw] read_only
  #   @return [::Boolean]
  #     Optional. Whether the disk is read only. If true, the disk may be
  #     shared by multiple VMs and
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     must be set.
  class GcePersistentDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#mount_path::String

Returns Required. Location of this directory in the running workstation.

Returns:

  • (::String)

    Required. Location of this directory in the running workstation.



835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 835

class EphemeralDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An EphemeralDirectory is backed by a Compute Engine persistent disk.
  # @!attribute [rw] disk_type
  #   @return [::String]
  #     Optional. Type of the disk to use. Defaults to `"pd-standard"`.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. Must
  #     be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_image source_image}
  #     is set. Must be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#read_only read_only}
  #     is false. Updating
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     will update content in the ephemeral directory after the workstation is
  #     restarted.
  #
  #     Only file systems supported by Container-Optimized OS (COS)
  #     are explicitly supported. For a list of supported file systems, see
  #     [the filesystems available in Container-Optimized
  #     OS](https://cloud.google.com/container-optimized-os/docs/concepts/supported-filesystems).
  #
  #     This field is mutable.
  # @!attribute [rw] source_image
  #   @return [::String]
  #     Optional. Name of the disk image to use as the source for the disk.
  #     Must be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     is set. Updating
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_image source_image}
  #     will update content in the ephemeral directory after the workstation is
  #     restarted.
  #
  #     Only file systems supported by Container-Optimized OS (COS)
  #     are explicitly supported. For a list of supported file systems, please
  #     refer to the [COS
  #     documentation](https://cloud.google.com/container-optimized-os/docs/concepts/supported-filesystems).
  #
  #     This field is mutable.
  # @!attribute [rw] read_only
  #   @return [::Boolean]
  #     Optional. Whether the disk is read only. If true, the disk may be
  #     shared by multiple VMs and
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::EphemeralDirectory::GcePersistentDisk#source_snapshot source_snapshot}
  #     must be set.
  class GcePersistentDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end