Class: Google::Cloud::Workstations::V1::WorkstationConfig::Host::GceInstance::BoostConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Workstations::V1::WorkstationConfig::Host::GceInstance::BoostConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workstations/v1/workstations.rb
Overview
A boost configuration is a set of resources that a workstation can use to increase its performance. If you specify a boost configuration, upon startup, workstation users can choose to use a VM provisioned under the boost config by passing the boost config ID in the start request. If the workstation user does not provide a boost config ID in the start request, the system will choose a VM from the pool provisioned under the default config.
Instance Attribute Summary collapse
-
#accelerators ⇒ ::Array<::Google::Cloud::Workstations::V1::WorkstationConfig::Host::GceInstance::Accelerator>
Optional.
-
#boot_disk_size_gb ⇒ ::Integer
Optional.
-
#enable_nested_virtualization ⇒ ::Boolean
Optional.
-
#id ⇒ ::String
Required.
-
#machine_type ⇒ ::String
Optional.
-
#pool_size ⇒ ::Integer
Optional.
Instance Attribute Details
#accelerators ⇒ ::Array<::Google::Cloud::Workstations::V1::WorkstationConfig::Host::GceInstance::Accelerator>
Returns Optional. A list of the type and count of accelerator cards attached
to the boost instance. Defaults to none.
642 643 644 645 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 642 class BoostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#boot_disk_size_gb ⇒ ::Integer
Returns Optional. The size of the boot disk for the VM in gigabytes (GB).
The minimum boot disk size is 30 GB. Defaults to 50 GB.
642 643 644 645 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 642 class BoostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#enable_nested_virtualization ⇒ ::Boolean
Returns Optional. Whether to enable nested virtualization on boosted Cloud Workstations VMs running using this boost configuration.
Defaults to false.
Nested virtualization lets you run virtual machine (VM) instances inside your workstation. Before enabling nested virtualization, consider the following important considerations. Cloud Workstations instances are subject to the same restrictions as Compute Engine instances:
- Organization policy: projects, folders, or organizations may be restricted from creating nested VMs if the Disable VM nested virtualization constraint is enforced in the organization policy. For more information, see the Compute Engine section, Checking whether nested virtualization is allowed.
- Performance: nested VMs might experience a 10% or greater decrease in performance for workloads that are CPU-bound and possibly greater than a 10% decrease for workloads that are input/output bound.
- Machine Type: nested virtualization can only be enabled on boost configurations that specify a machine_type in the N1 or N2 machine series.
642 643 644 645 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 642 class BoostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String
Returns Required. The ID to be used for the boost configuration.
642 643 644 645 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 642 class BoostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#machine_type ⇒ ::String
Returns Optional. The type of machine that boosted VM instances will use—for
example, e2-standard-4. For more information about machine types
that Cloud Workstations supports, see the list of available machine
types.
Defaults to e2-standard-4.
642 643 644 645 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 642 class BoostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pool_size ⇒ ::Integer
Returns Optional. The number of boost VMs that the system should keep idle so
that workstations can be boosted quickly. Defaults to 0.
642 643 644 645 |
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 642 class BoostConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |