Class: Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workstations/v1/workstations.rb

Overview

A directory to persist across workstation sessions. Updates to this field will not update existing workstations and will only take effect on new workstations.

Defined Under Namespace

Classes: GceHyperdiskBalancedHighAvailability, GceRegionalPersistentDisk

Instance Attribute Summary collapse

Instance Attribute Details

#gce_hd::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability

Returns A PersistentDirectory backed by a Compute Engine hyperdisk high availability disk.

Note: The following fields are mutually exclusive: gce_hd, gce_pd. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 684

class PersistentDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Persistent Directory backed by a Compute Engine regional persistent
  # disk. The
  # {::Google::Cloud::Workstations::V1::WorkstationConfig#persistent_directories persistent_directories}
  # field is repeated, but it may contain only one entry. It creates a
  # [persistent
  # disk](https://cloud.google.com/compute/docs/disks/persistent-disks) that
  # mounts to the workstation VM at `/home` when the session starts and
  # detaches when the session ends. If this field is empty, workstations
  # created with this configuration do not have a persistent home
  # directory.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`. If less than `200` GB, the
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#disk_type disk_type}
  #     must be
  #     `"pd-balanced"` or `"pd-ssd"`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] fs_type
  #   @return [::String]
  #     Optional. Type of file system that the disk should be formatted with.
  #     The workstation image must support this file system type. Must be empty
  #     if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set. Defaults to `"ext4"`.
  # @!attribute [rw] disk_type
  #   @return [::String]
  #     Optional. The [type of the persistent
  #     disk](https://cloud.google.com/compute/docs/disks#disk-types) for the
  #     home directory. Defaults to `"pd-standard"`.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#size_gb size_gb}
  #     and
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#fs_type fs_type}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceRegionalPersistentDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end

  # A Persistent Directory backed by a Compute Engine
  # [Hyperdisk Balanced High Availability
  # Disk](https://cloud.google.com/compute/docs/disks/hd-types/hyperdisk-balanced-ha).
  # This is a high-availability block storage solution that offers a balance
  # between performance and cost for most general-purpose workloads.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#size_gb size_gb}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceHyperdiskBalancedHighAvailability
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end
end

#gce_pd::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk

Returns A PersistentDirectory backed by a Compute Engine persistent disk.

Note: The following fields are mutually exclusive: gce_pd, gce_hd. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 684

class PersistentDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Persistent Directory backed by a Compute Engine regional persistent
  # disk. The
  # {::Google::Cloud::Workstations::V1::WorkstationConfig#persistent_directories persistent_directories}
  # field is repeated, but it may contain only one entry. It creates a
  # [persistent
  # disk](https://cloud.google.com/compute/docs/disks/persistent-disks) that
  # mounts to the workstation VM at `/home` when the session starts and
  # detaches when the session ends. If this field is empty, workstations
  # created with this configuration do not have a persistent home
  # directory.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`. If less than `200` GB, the
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#disk_type disk_type}
  #     must be
  #     `"pd-balanced"` or `"pd-ssd"`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] fs_type
  #   @return [::String]
  #     Optional. Type of file system that the disk should be formatted with.
  #     The workstation image must support this file system type. Must be empty
  #     if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set. Defaults to `"ext4"`.
  # @!attribute [rw] disk_type
  #   @return [::String]
  #     Optional. The [type of the persistent
  #     disk](https://cloud.google.com/compute/docs/disks#disk-types) for the
  #     home directory. Defaults to `"pd-standard"`.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#size_gb size_gb}
  #     and
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#fs_type fs_type}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceRegionalPersistentDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end

  # A Persistent Directory backed by a Compute Engine
  # [Hyperdisk Balanced High Availability
  # Disk](https://cloud.google.com/compute/docs/disks/hd-types/hyperdisk-balanced-ha).
  # This is a high-availability block storage solution that offers a balance
  # between performance and cost for most general-purpose workloads.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#size_gb size_gb}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceHyperdiskBalancedHighAvailability
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end
end

#mount_path::String

Returns Optional. Location of this directory in the running workstation.

Returns:

  • (::String)

    Optional. Location of this directory in the running workstation.



684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
# File 'proto_docs/google/cloud/workstations/v1/workstations.rb', line 684

class PersistentDirectory
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A Persistent Directory backed by a Compute Engine regional persistent
  # disk. The
  # {::Google::Cloud::Workstations::V1::WorkstationConfig#persistent_directories persistent_directories}
  # field is repeated, but it may contain only one entry. It creates a
  # [persistent
  # disk](https://cloud.google.com/compute/docs/disks/persistent-disks) that
  # mounts to the workstation VM at `/home` when the session starts and
  # detaches when the session ends. If this field is empty, workstations
  # created with this configuration do not have a persistent home
  # directory.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`. If less than `200` GB, the
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#disk_type disk_type}
  #     must be
  #     `"pd-balanced"` or `"pd-ssd"`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] fs_type
  #   @return [::String]
  #     Optional. Type of file system that the disk should be formatted with.
  #     The workstation image must support this file system type. Must be empty
  #     if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#source_snapshot source_snapshot}
  #     is set. Defaults to `"ext4"`.
  # @!attribute [rw] disk_type
  #   @return [::String]
  #     Optional. The [type of the persistent
  #     disk](https://cloud.google.com/compute/docs/disks#disk-types) for the
  #     home directory. Defaults to `"pd-standard"`.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#size_gb size_gb}
  #     and
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk#fs_type fs_type}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceRegionalPersistentDisk::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceRegionalPersistentDisk
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end

  # A Persistent Directory backed by a Compute Engine
  # [Hyperdisk Balanced High Availability
  # Disk](https://cloud.google.com/compute/docs/disks/hd-types/hyperdisk-balanced-ha).
  # This is a high-availability block storage solution that offers a balance
  # between performance and cost for most general-purpose workloads.
  # @!attribute [rw] size_gb
  #   @return [::Integer]
  #     Optional. The GB capacity of a persistent home directory for each
  #     workstation created with this configuration. Must be empty if
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#source_snapshot source_snapshot}
  #     is set.
  #
  #     Valid values are `10`, `50`, `100`, `200`, `500`, or `1000`.
  #     Defaults to `200`.
  # @!attribute [rw] max_size_gb
  #   @return [::Integer]
  #     Optional. Maximum size in GB to which this persistent directory can be
  #     resized. Defaults to unlimited if not set.
  # @!attribute [rw] source_snapshot
  #   @return [::String]
  #     Optional. Name of the snapshot to use as the source for the disk. If
  #     set,
  #     {::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability#size_gb size_gb}
  #     must be empty. Must be formatted as ext4 file system with no
  #     partitions.
  # @!attribute [rw] reclaim_policy
  #   @return [::Google::Cloud::Workstations::V1::WorkstationConfig::PersistentDirectory::GceHyperdiskBalancedHighAvailability::ReclaimPolicy]
  #     Optional. Whether the persistent disk should be deleted when the
  #     workstation is deleted. Valid values are `DELETE` and `RETAIN`.
  #     Defaults to `DELETE`.
  # @!attribute [rw] archive_timeout
  #   @return [::Google::Protobuf::Duration]
  #     Optional. Number of seconds to wait after initially creating or
  #     subsequently shutting down the workstation before converting its disk
  #     into a snapshot. This generally saves costs at the expense of greater
  #     startup time on next workstation start, as the service will need to
  #     create a disk from the archival snapshot.
  #
  #     A value of `"0s"` indicates that the disk will never be archived.
  class GceHyperdiskBalancedHighAvailability
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Value representing what should happen to the disk after the workstation
    # is deleted.
    module ReclaimPolicy
      # Do not use.
      RECLAIM_POLICY_UNSPECIFIED = 0

      # Delete the persistent disk when deleting the workstation.
      DELETE = 1

      # Keep the persistent disk when deleting the workstation.
      # An administrator must manually delete the disk.
      RETAIN = 2
    end
  end
end